@@ -2,7 +2,10 @@ import logging
 from vortex.sqla_orm.OrmCrudHandler import OrmCrudHandler
 
 from peek_plugin_docdb_generic_menu._private.PluginNames import docDbGenericMenuFilt
-from peek_plugin_docdb_generic_menu._private.storage.Setting import SettingProperty, globalSetting
+from peek_plugin_docdb_generic_menu._private.storage.Setting import (
+    SettingProperty,
+    globalSetting,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -21,8 +24,9 @@ class __CrudHandler(OrmCrudHandler):
 
 # This method creates an instance of the handler class.
 def makeSettingPropertyHandler(dbSessionCreator):
-    handler = __CrudHandler(dbSessionCreator, SettingProperty,
-                            filtKey, retreiveAll=True)
+    handler = __CrudHandler(
+        dbSessionCreator, SettingProperty, filtKey, retreiveAll=True
+    )
 
     logger.debug("Started")
-    return handler
\ No newline at end of file
+    return handler
